pub trait NonDualStackDatagramBoundStateContext<I: IpExt, BC, S: DatagramSocketSpec>: DeviceIdContext<AnyDevice> {
// Required method
fn nds_converter(
&self,
) -> impl NonDualStackConverter<I, Self::WeakDeviceId, S>;
}Expand description
Provides access to socket state for a single IP version.
Required Methods
Sourcefn nds_converter(&self) -> impl NonDualStackConverter<I, Self::WeakDeviceId, S>
fn nds_converter(&self) -> impl NonDualStackConverter<I, Self::WeakDeviceId, S>
Returns an instance of a type that implements NonDualStackConverter
for addresses.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".