pub type StrongRc<I, D, S> = StrongRc<ReferenceState<I, D, S>>;Expand description
A convenient alias for a strong reference to a datagram socket.
Aliased Type
pub struct StrongRc<I, D, S> { /* private fields */ }pub type StrongRc<I, D, S> = StrongRc<ReferenceState<I, D, S>>;A convenient alias for a strong reference to a datagram socket.
pub struct StrongRc<I, D, S> { /* private fields */ }