pub type WeakRc<I, D, S> = WeakRc<ReferenceState<I, D, S>>;Expand description
A convenient alias for a weak reference to a datagram socket.
Aliased Type
pub struct WeakRc<I, D, S>(/* private fields */);pub type WeakRc<I, D, S> = WeakRc<ReferenceState<I, D, S>>;A convenient alias for a weak reference to a datagram socket.
pub struct WeakRc<I, D, S>(/* private fields */);